==> inkribbon-6.x-5.7.tar.gz: inkribbon/templates/maintenance-page.tpl.php <==
<?php
// $Id: maintenance-page.tpl.php,v 1.1.2.17 2010/05/12 22:47:59 mverbaar Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">
  
  <div id="page-wrapper"><div id="page">
    
    <div id="header-wrapper"><div id="header" class="clear-block">
      
      <?php if ($logo): ?>
        <div id="logo"><?php print $logo; ?></div>
      <?php endif; ?>

      <?php if ($site_name): ?>
        <?php
          // Use h1 when the page title is empty.
          $site_name_wrapper = ($title) ? 'div' : 'h1';
        ?>
        <<?php print $site_name_wrapper; ?> id="site-name">
          <?php print $site_name; ?>
        </<?php print $site_name_wrapper; ?>>
      <?php endif; ?>

      <?php if ($site_slogan): ?>
        <div id="site-slogan"><?php print $site_slogan; ?></div>
      <?php endif; ?>

      <?php if ($header): ?>
        <div class="region region-header">
          <?php print $header; ?>
        </div>
      <?php endif; ?>
      
    </div></div> <!-- /#header, /#header-wrapper -->
    
    <?php if ($messages): ?>
      <div id="console"><?php print $messages; ?></div>
    <?php endif; ?>

    <div id="main-wrapper"><div id="main" class="clear-block">

      <div id="content" class="column">
        <?php if ($highlight): ?>
          <div class="region region-higlight">
            <?php print $highlight; ?>
          </div>
        <?php endif; ?>
        
        <?php print $breadcrumb; ?>
        
        <?php if ($title): ?>
          <h1 id="page-title"><?php print $title; ?></h1>
        <?php endif; ?>
        
        <?php print $tabs; ?>
        <?php print $help; ?>
        <div class="region region-content">
          <?php print $content; ?>
        </div>
      </div> <!-- /#content -->
      
      <?php if ($left): ?>
        <div id="sidebar-left" class="column sidebar">
          <div class="region region-sidebar-left">
            <?php print $left; ?>
          </div>
        </div> <!-- /#sidebar-left -->
      <?php endif; ?>

      <?php if ($right): ?>
        <div id="sidebar-right" class="column sidebar">
          <div class="region region-sidebar-right">
            <?php print $right; ?>
          </div>
        </div> <!-- /#sidebar-right -->
      <?php endif; ?>

    </div></div> <!-- /#main, /#main-wrapper -->

    <?php if ($footer): ?>
      <div id="footer-wrapper"><div id="footer" class="clear-block">
        <div class="region region-footer">
          <?php print $footer; ?>
        </div>
      </div></div> <!-- /#footer, /#footer-wrapper -->
    <?php endif; ?>

  </div></div> <!-- /#page, /#page-wrapper -->
  
  <?php print $closure; ?>

</body>
</html>

==> inkribbon-6.x-5.11.tar.gz: inkribbon/templates/maintenance-page.tpl.php <==
<?php
// $Id: maintenance-page.tpl.php,v 1.1.2.18 2010/05/28 21:29:36 mverbaar Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">
  
  <div id="page-wrapper"><div id="page">
    
    <div id="header-wrapper"><div id="header" class="clear-block">
      
      <?php if ($logo): ?>
        <div id="logo">
          <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><?php print $logo; ?></a>
        </div>
      <?php endif; ?>

      <?php if ($site_name): ?>
        <?php
          // Use h1 when the page title is empty.
          $site_name_wrapper = ($title) ? 'div' : 'h1';
        ?>
        <<?php print $site_name_wrapper; ?> id="site-name">
          <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><?php print $site_name; ?></a>
        </<?php print $site_name_wrapper; ?>>
      <?php endif; ?>

      <?php if ($site_slogan): ?>
        <div id="site-slogan"><?php print $site_slogan; ?></div>
      <?php endif; ?>

      <?php if ($header): ?>
        <div class="region region-header">
          <?php print $header; ?>
        </div>
      <?php endif; ?>
      
    </div></div> <!-- /#header, /#header-wrapper -->
    
    <?php if ($messages): ?>
      <div id="console"><?php print $messages; ?></div>
    <?php endif; ?>

    <div id="main-wrapper"><div id="main" class="clear-block">

      <div id="content" class="column">
        <?php if ($highlight): ?>
          <div id="highlight">
            <div class="region region-highlight">
              <?php print $highlight; ?>
            </div>
          </div>
        <?php endif; ?>
        
        <?php print $breadcrumb; ?>
        
        <?php if ($title): ?>
          <h1 id="page-title"><?php print $title; ?></h1>
        <?php endif; ?>
        
        <?php print $tabs; ?>
        <?php print $help; ?>
        <div class="region region-content">
          <?php print $content; ?>
        </div>
      </div> <!-- /#content -->
      
      <?php if ($left): ?>
        <div id="sidebar-left" class="column sidebar">
          <div class="region region-sidebar-left">
            <?php print $left; ?>
          </div>
        </div> <!-- /#sidebar-left -->
      <?php endif; ?>

      <?php if ($right): ?>
        <div id="sidebar-right" class="column sidebar">
          <div class="region region-sidebar-right">
            <?php print $right; ?>
          </div>
        </div> <!-- /#sidebar-right -->
      <?php endif; ?>

    </div></div> <!-- /#main, /#main-wrapper -->

    <?php if ($footer): ?>
      <div id="footer-wrapper"><div id="footer" class="clear-block">
        <div class="region region-footer">
          <?php print $footer; ?>
        </div>
      </div></div> <!-- /#footer, /#footer-wrapper -->
    <?php endif; ?>

  </div></div> <!-- /#page, /#page-wrapper -->
  
  <?php print $closure; ?>

</body>
</html>
